Shadow

Struct Shadow 

pub struct Shadow {
    pub offset: [i8; 2],
    pub blur: u8,
    pub spread: u8,
    pub color: Color32,
}
The color and fuzziness of a fuzzy shape.

Can be used for a rectangular shadow with a soft penumbra.

Very similar to a box-shadow in CSS.

Fields

offset: [i8; 2]

Move the shadow by this much.

For instance, a value of [1.0, 2.0] will move the shadow 1 point to the right and 2 points down, causing a drop-shadow effect.

blur: u8

The width of the blur, i.e. the width of the fuzzy penumbra.

A value of 0 means a sharp shadow.

spread: u8

Expand the shadow in all directions by this much.

color: Color32

Color of the opaque center of the shadow.

Implementations

Source

impl Shadow

pub const NONE: Self

No shadow at all.

pub fn as_shape( &self, rect: Rect, corner_radius: impl Into<CornerRadius>, ) -> RectShape

The argument is the rectangle of the shadow caster.

pub fn margin(&self) -> MarginF32

How much larger than the parent rect are we in each direction?