pub enum FontPriority {
Highest,
Lowest,
}Variants
Highest
Prefer this font before all existing ones.
If a desired glyph exists in this font, it will be used.
Lowest
Use this font as a fallback, after all existing ones.
This font will only be used if the glyph is not found in any of the previously installed fonts.