pub struct TextOptions {
pub max_texture_side: usize,
pub color_transfer_function: FontColorTransferFunction,
pub font_hinting: bool,
pub subpixel_binning: bool,
}Expand description
Controls how we render text
Fields
max_texture_side: usizeMaximum size of the font texture.
color_transfer_function: FontColorTransferFunctionControls how to convert glyph colors when writing to the font atlas.
font_hinting: boolWhether to enable font hinting
(round some font coordinates to pixels for sharper text).
Default is true.
subpixel_binning: boolEnable sub-pixel binning for glyphs.
Sub-pixel binning renders each glyph at up to four fractional horizontal offsets, giving more even kerning at the cost of more atlas space.
It also lead to text looking more blurry.
This is always disabled for CJK characters (which have too many unique glyphs).
Can be overridden per font with FontTweak::subpixel_binning.
Default: true.